@@ -1,8 +1,9 @@
 #' Displays R Colors
 #'
 #' @return No value returned
-#' @description Produces plot of colors available in R. Numeric labels same for whole row.
-#' @examples Colors()
+#' @description Produces plot of colors available in R. Colored cells labels with numeric value that corresponds to that color. No values supplied to function.
+#' @examples 
+#'   Colors()
 #' @export
 #'
 
@@ -20,11 +21,20 @@ Colors = function()
         remaining <- length(grDevices::colors()) - base
         RowSize <- ifelse(remaining < colCount, remaining, colCount)
         thisColorRect = grDevices::colors()[base + (1:RowSize)]
-        thisColorText = SetTextContrastColor(thisColorRect)
-        graphics::rect((1:RowSize)-0.5,j-0.5, (1:RowSize)+0.5,j+0.5,
+        
+        thisColorText = rep(NA, length(thisColorRect))
+        for(i in 1:length(thisColorRect))
+        {
+          thisColorText[i] = SetTextContrastColor(thisColorRect[i])
+        }
+        graphics::rect((1:RowSize)-0.5, j-0.5, (1:RowSize)+0.5, j+0.5,
            border="black",
            col=thisColorRect)
-        graphics::text((1:RowSize), j, paste(base + (1:RowSize)), cex=0.7,
+        graphics::text((1:RowSize), j, paste(base + (1:RowSize)), cex=0.6,
            col=thisColorText)  # 
       }
+    
     }
+
+
+
